import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import DeliveryItemCreate from "./DeliveryItemCreate";
import DeliveryItemPanel from "./DeliveryItemPanel";
import EmptyData from "../components/EmptyData";
import MyCreateButton from "../components/MyCreateButton";
import MyExportButton from '../components/MyExportButton';
import PageDrawer from "../components/PageDrawer";
import MyField from "../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <DateInput label='common.time.after' source="timeStart" alwaysOn />,
    <DateInput label='common.time.before' source="timeEnd" alwaysOn />,

    <NumberInput source="deliveryId" label="table.field.deliveryItem.deliveryId" />,
    <TextInput source="platItemId" label="table.field.deliveryItem.platItemId" />,
    <TextInput source="matnrCode" label="table.field.deliveryItem.matnrCode" />,
    <TextInput source="matnrName" label="table.field.deliveryItem.matnrName" />,
    <TextInput source="fieldsIndex" label="table.field.deliveryItem.fieldsIndex" />,
    <TextInput source="unit" label="table.field.deliveryItem.unit" />,
    <NumberInput source="anfme" label="table.field.deliveryItem.anfme" />,
    <NumberInput source="qty" label="table.field.deliveryItem.qty" />,
    <NumberInput source="nromQty" label="table.field.deliveryItem.nromQty" />,
    <NumberInput source="printQty" label="table.field.deliveryItem.printQty" />,
    <TextInput source="splrName" label="table.field.deliveryItem.splrName" />,
    <TextInput source="splrCode" label="table.field.deliveryItem.splrCode" />,
    <TextInput source="splrBatch" label="table.field.deliveryItem.splrBatch" />,

    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const DeliveryItemList = () => {
    const translate = useTranslate();

    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);

    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: !!drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.deliveryItem"}
                empty={<EmptyData onClick={() => { setCreateDialog(true) }} />}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <MyCreateButton onClick={() => { setCreateDialog(true) }} />
                        <SelectColumnsButton preferenceKey='deliveryItem' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='deliveryItem'
                    bulkActionButtons={() => <BulkDeleteButton mutationMode={OPERATE_MODE} />}
                    rowClick={(id, resource, record) => false}
                    expand={() => <DeliveryItemPanel />}
                    expandSingle={true}
                    omit={['id', 'createTime', 'createBy', 'memo']}
                >
                    <NumberField source="id" />
                    <NumberField source="deliveryId" label="table.field.deliveryItem.deliveryId" />
                    <TextField source="platItemId" label="table.field.deliveryItem.platItemId" />
                    <TextField source="matnrCode" label="table.field.deliveryItem.matnrCode" />
                    <TextField source="matnrName" label="table.field.deliveryItem.matnrName" />
                    <TextField source="fieldsIndex" label="table.field.deliveryItem.fieldsIndex" />
                    <TextField source="unit" label="table.field.deliveryItem.unit" />
                    <NumberField source="anfme" label="table.field.deliveryItem.anfme" />
                    <NumberField source="qty" label="table.field.deliveryItem.qty" />
                    <NumberField source="nromQty" label="table.field.deliveryItem.nromQty" />
                    <NumberField source="printQty" label="table.field.deliveryItem.printQty" />
                    <TextField source="splrName" label="table.field.deliveryItem.splrName" />
                    <TextField source="splrCode" label="table.field.deliveryItem.splrCode" />
                    <TextField source="splrBatch" label="table.field.deliveryItem.splrBatch" />

                    <ReferenceField source="updateBy" label="common.field.updateBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <ReferenceField source="createBy" label="common.field.createBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="createTime" label="common.field.createTime" showTime />
                    <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                    <WrapperField cellClassName="opt" label="common.field.opt">
                        <EditButton sx={{ padding: '1px', fontSize: '.75rem' }} />
                        <DeleteButton sx={{ padding: '1px', fontSize: '.75rem' }} mutationMode={OPERATE_MODE} />
                    </WrapperField>
                </StyledDatagrid>
            </List>
            <DeliveryItemCreate
                open={createDialog}
                setOpen={setCreateDialog}
            />
            <PageDrawer
                title='DeliveryItem Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default DeliveryItemList;
